Links to SNN training frameworks
================================

Tonic takes care of providing you with the right data in the right format. In order to train your spiking neural network, we refer the reader to a list of simulators in alphabetical order:

* `BindsNet <https://github.com/BindsNET/bindsnet>`_
* `Norse documentation <https://norse.github.io/norse/>`_ and `tutorial using Tonic and Norse <https://github.com/norse/notebooks/blob/master/poker-dvs_classifier.ipynb>`_.
* `Rockpool <https://rockpool.ai/>`_
* `Sinabs <https://sinabs.ai/>`_
* `snnTorch documentation <https://snntorch.readthedocs.io/>`_ and `tutorial using Tonic and snnTorch <https://snntorch.readthedocs.io/en/latest/tutorials/tutorial_7.html>`_.
